@@ -9,8 +9,9 @@ from django.utils.translation import gettext_lazy as _
 class SimpelPagesConfig(AppConfig):
     default_auto_field = 'django.db.models.BigAutoField'
     name = "simpel_pages"
+    icon = "page-next-outline"
     label = "simpel_pages"
-    verbose_name = _("Simpel Pages")
+    verbose_name = _("Pages")
 
     def ready(self):
         post_migrate.connect(init_app, sender=self)
@@ -19,10 +20,9 @@ class SimpelPagesConfig(AppConfig):
 def init_app(sender, **kwargs):
     """after migrations"""
     from django.contrib.sites.models import Site
-
     from simpel_themes.models import PathModelTemplate
 
-    from simpel_pages.models import Page
+    from .models import Page
 
     name = getattr(settings, "SITE_NAME", "Simpel")
     domain = getattr(settings, "SITE_DOMAIN", "127.0.0.1:8000")
