@@ -1,6 +1,6 @@
 from django.urls import path
 
-from simpel_pages import views
+from . import views
 
 urlpatterns = [
     path("", views.simpelpage, name="simpelpage"),
